/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = function() {
  this.Before("@cloudsearch", function (callback) {
    this.service = new this.AWS.CloudSearch.Client();
    callback();
  });

  this.Given(/^I create a domain with name prefix "([^"]*)"$/, function(prefix, callback) {
    this.domainName = this.uniqueName(prefix);
    this.request(null, 'createDomain', {DomainName: this.domainName}, callback, false);
  });

  this.Given(/^I define a CloudSearch index field with source attributes$/, function(callback) {
    var params = {
      DomainName: this.domainName,
      IndexField: {
        IndexFieldName: 'fieldname',
        IndexFieldType: 'text',
        SourceAttributes: [{
          SourceDataFunction: 'Map',
          SourceDataMap: {
            SourceName: 'sourcedata',
            Cases: {
              case1: 'value1',
              case2: 'value2'
            }
          }
        }]
      }
    };
    this.request(null, 'defineIndexField', params, callback);
  });

  this.Then(/^DomainStatus should show that Created is true$/, function(callback) {
    this.assert.equal(this.data.DomainStatus.Created, true);
    callback();
  });
};
