/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'query',
  apiVersion: '2011-02-01',
  endpointPrefix: 'cloudsearch',
  resultWrapped: true,
  serviceFullName: 'Amazon CloudSearch',
  signatureVersion: 'v4',
  timestampFormat: 'iso8601',
  operations: {
    createDomain: {
      name: 'CreateDomain',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          DomainStatus: {
            type: 'structure',
            members: {
              DomainId: {
              },
              DomainName: {
              },
              Created: {
                type: 'boolean'
              },
              Deleted: {
                type: 'boolean'
              },
              NumSearchableDocs: {
                type: 'integer'
              },
              DocService: {
                type: 'structure',
                members: {
                  Arn: {
                  },
                  Endpoint: {
                  }
                }
              },
              SearchService: {
                type: 'structure',
                members: {
                  Arn: {
                  },
                  Endpoint: {
                  }
                }
              },
              RequiresIndexDocuments: {
                type: 'boolean'
              },
              Processing: {
                type: 'boolean'
              },
              SearchInstanceType: {
              },
              SearchPartitionCount: {
                type: 'integer'
              },
              SearchInstanceCount: {
                type: 'integer'
              }
            }
          }
        }
      }
    },
    defineIndexField: {
      name: 'DefineIndexField',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          IndexField: {
            type: 'structure',
            members: {
              IndexFieldName: {
                required: true
              },
              IndexFieldType: {
                required: true
              },
              UIntOptions: {
                type: 'structure',
                members: {
                  DefaultValue: {
                    type: 'integer'
                  }
                }
              },
              LiteralOptions: {
                type: 'structure',
                members: {
                  DefaultValue: {
                  },
                  SearchEnabled: {
                    type: 'boolean'
                  },
                  FacetEnabled: {
                    type: 'boolean'
                  },
                  ResultEnabled: {
                    type: 'boolean'
                  }
                }
              },
              TextOptions: {
                type: 'structure',
                members: {
                  DefaultValue: {
                  },
                  FacetEnabled: {
                    type: 'boolean'
                  },
                  ResultEnabled: {
                    type: 'boolean'
                  },
                  TextProcessor: {
                  }
                }
              },
              SourceAttributes: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    SourceDataFunction: {
                      required: true
                    },
                    SourceDataCopy: {
                      type: 'structure',
                      members: {
                        SourceName: {
                          required: true
                        },
                        DefaultValue: {
                        }
                      }
                    },
                    SourceDataTrimTitle: {
                      type: 'structure',
                      members: {
                        SourceName: {
                          required: true
                        },
                        DefaultValue: {
                        },
                        Separator: {
                        },
                        Language: {
                        }
                      }
                    },
                    SourceDataMap: {
                      type: 'structure',
                      members: {
                        SourceName: {
                          required: true
                        },
                        DefaultValue: {
                        },
                        Cases: {
                          type: 'map',
                          keys: {
                          },
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          IndexField: {
            type: 'structure',
            members: {
              Options: {
                type: 'structure',
                members: {
                  IndexFieldName: {
                  },
                  IndexFieldType: {
                  },
                  UIntOptions: {
                    type: 'structure',
                    members: {
                      DefaultValue: {
                        type: 'integer'
                      }
                    }
                  },
                  LiteralOptions: {
                    type: 'structure',
                    members: {
                      DefaultValue: {
                      },
                      SearchEnabled: {
                        type: 'boolean'
                      },
                      FacetEnabled: {
                        type: 'boolean'
                      },
                      ResultEnabled: {
                        type: 'boolean'
                      }
                    }
                  },
                  TextOptions: {
                    type: 'structure',
                    members: {
                      DefaultValue: {
                      },
                      FacetEnabled: {
                        type: 'boolean'
                      },
                      ResultEnabled: {
                        type: 'boolean'
                      },
                      TextProcessor: {
                      }
                    }
                  },
                  SourceAttributes: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        SourceDataFunction: {
                        },
                        SourceDataCopy: {
                          type: 'structure',
                          members: {
                            SourceName: {
                            },
                            DefaultValue: {
                            }
                          }
                        },
                        SourceDataTrimTitle: {
                          type: 'structure',
                          members: {
                            SourceName: {
                            },
                            DefaultValue: {
                            },
                            Separator: {
                            },
                            Language: {
                            }
                          }
                        },
                        SourceDataMap: {
                          type: 'structure',
                          members: {
                            SourceName: {
                            },
                            DefaultValue: {
                            },
                            Cases: {
                              type: 'map',
                              keys: {
                              },
                              members: {
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    defineRankExpression: {
      name: 'DefineRankExpression',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          RankExpression: {
            type: 'structure',
            members: {
              RankName: {
                required: true
              },
              RankExpression: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          RankExpression: {
            type: 'structure',
            members: {
              Options: {
                type: 'structure',
                members: {
                  RankName: {
                  },
                  RankExpression: {
                  }
                }
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    deleteDomain: {
      name: 'DeleteDomain',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          DomainStatus: {
            type: 'structure',
            members: {
              DomainId: {
              },
              DomainName: {
              },
              Created: {
                type: 'boolean'
              },
              Deleted: {
                type: 'boolean'
              },
              NumSearchableDocs: {
                type: 'integer'
              },
              DocService: {
                type: 'structure',
                members: {
                  Arn: {
                  },
                  Endpoint: {
                  }
                }
              },
              SearchService: {
                type: 'structure',
                members: {
                  Arn: {
                  },
                  Endpoint: {
                  }
                }
              },
              RequiresIndexDocuments: {
                type: 'boolean'
              },
              Processing: {
                type: 'boolean'
              },
              SearchInstanceType: {
              },
              SearchPartitionCount: {
                type: 'integer'
              },
              SearchInstanceCount: {
                type: 'integer'
              }
            }
          }
        }
      }
    },
    deleteIndexField: {
      name: 'DeleteIndexField',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          IndexFieldName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          IndexField: {
            type: 'structure',
            members: {
              Options: {
                type: 'structure',
                members: {
                  IndexFieldName: {
                  },
                  IndexFieldType: {
                  },
                  UIntOptions: {
                    type: 'structure',
                    members: {
                      DefaultValue: {
                        type: 'integer'
                      }
                    }
                  },
                  LiteralOptions: {
                    type: 'structure',
                    members: {
                      DefaultValue: {
                      },
                      SearchEnabled: {
                        type: 'boolean'
                      },
                      FacetEnabled: {
                        type: 'boolean'
                      },
                      ResultEnabled: {
                        type: 'boolean'
                      }
                    }
                  },
                  TextOptions: {
                    type: 'structure',
                    members: {
                      DefaultValue: {
                      },
                      FacetEnabled: {
                        type: 'boolean'
                      },
                      ResultEnabled: {
                        type: 'boolean'
                      },
                      TextProcessor: {
                      }
                    }
                  },
                  SourceAttributes: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        SourceDataFunction: {
                        },
                        SourceDataCopy: {
                          type: 'structure',
                          members: {
                            SourceName: {
                            },
                            DefaultValue: {
                            }
                          }
                        },
                        SourceDataTrimTitle: {
                          type: 'structure',
                          members: {
                            SourceName: {
                            },
                            DefaultValue: {
                            },
                            Separator: {
                            },
                            Language: {
                            }
                          }
                        },
                        SourceDataMap: {
                          type: 'structure',
                          members: {
                            SourceName: {
                            },
                            DefaultValue: {
                            },
                            Cases: {
                              type: 'map',
                              keys: {
                              },
                              members: {
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    deleteRankExpression: {
      name: 'DeleteRankExpression',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          RankName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          RankExpression: {
            type: 'structure',
            members: {
              Options: {
                type: 'structure',
                members: {
                  RankName: {
                  },
                  RankExpression: {
                  }
                }
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    describeDefaultSearchField: {
      name: 'DescribeDefaultSearchField',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          DefaultSearchField: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    describeDomains: {
      name: 'DescribeDomains',
      input: {
        type: 'structure',
        members: {
          DomainNames: {
            type: 'list',
            members: {
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          DomainStatusList: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                DomainId: {
                },
                DomainName: {
                },
                Created: {
                  type: 'boolean'
                },
                Deleted: {
                  type: 'boolean'
                },
                NumSearchableDocs: {
                  type: 'integer'
                },
                DocService: {
                  type: 'structure',
                  members: {
                    Arn: {
                    },
                    Endpoint: {
                    }
                  }
                },
                SearchService: {
                  type: 'structure',
                  members: {
                    Arn: {
                    },
                    Endpoint: {
                    }
                  }
                },
                RequiresIndexDocuments: {
                  type: 'boolean'
                },
                Processing: {
                  type: 'boolean'
                },
                SearchInstanceType: {
                },
                SearchPartitionCount: {
                  type: 'integer'
                },
                SearchInstanceCount: {
                  type: 'integer'
                }
              }
            }
          }
        }
      }
    },
    describeIndexFields: {
      name: 'DescribeIndexFields',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          FieldNames: {
            type: 'list',
            members: {
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          IndexFields: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Options: {
                  type: 'structure',
                  members: {
                    IndexFieldName: {
                    },
                    IndexFieldType: {
                    },
                    UIntOptions: {
                      type: 'structure',
                      members: {
                        DefaultValue: {
                          type: 'integer'
                        }
                      }
                    },
                    LiteralOptions: {
                      type: 'structure',
                      members: {
                        DefaultValue: {
                        },
                        SearchEnabled: {
                          type: 'boolean'
                        },
                        FacetEnabled: {
                          type: 'boolean'
                        },
                        ResultEnabled: {
                          type: 'boolean'
                        }
                      }
                    },
                    TextOptions: {
                      type: 'structure',
                      members: {
                        DefaultValue: {
                        },
                        FacetEnabled: {
                          type: 'boolean'
                        },
                        ResultEnabled: {
                          type: 'boolean'
                        },
                        TextProcessor: {
                        }
                      }
                    },
                    SourceAttributes: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          SourceDataFunction: {
                          },
                          SourceDataCopy: {
                            type: 'structure',
                            members: {
                              SourceName: {
                              },
                              DefaultValue: {
                              }
                            }
                          },
                          SourceDataTrimTitle: {
                            type: 'structure',
                            members: {
                              SourceName: {
                              },
                              DefaultValue: {
                              },
                              Separator: {
                              },
                              Language: {
                              }
                            }
                          },
                          SourceDataMap: {
                            type: 'structure',
                            members: {
                              SourceName: {
                              },
                              DefaultValue: {
                              },
                              Cases: {
                                type: 'map',
                                keys: {
                                },
                                members: {
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                },
                Status: {
                  type: 'structure',
                  members: {
                    CreationDate: {
                      type: 'timestamp'
                    },
                    UpdateDate: {
                      type: 'timestamp'
                    },
                    UpdateVersion: {
                      type: 'integer'
                    },
                    State: {
                    },
                    PendingDeletion: {
                      type: 'boolean'
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    describeRankExpressions: {
      name: 'DescribeRankExpressions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          RankNames: {
            type: 'list',
            members: {
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          RankExpressions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Options: {
                  type: 'structure',
                  members: {
                    RankName: {
                    },
                    RankExpression: {
                    }
                  }
                },
                Status: {
                  type: 'structure',
                  members: {
                    CreationDate: {
                      type: 'timestamp'
                    },
                    UpdateDate: {
                      type: 'timestamp'
                    },
                    UpdateVersion: {
                      type: 'integer'
                    },
                    State: {
                    },
                    PendingDeletion: {
                      type: 'boolean'
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    describeServiceAccessPolicies: {
      name: 'DescribeServiceAccessPolicies',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          AccessPolicies: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    describeStemmingOptions: {
      name: 'DescribeStemmingOptions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Stems: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    describeStopwordOptions: {
      name: 'DescribeStopwordOptions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Stopwords: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    describeSynonymOptions: {
      name: 'DescribeSynonymOptions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Synonyms: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    indexDocuments: {
      name: 'IndexDocuments',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          FieldNames: {
            type: 'list',
            members: {
            }
          }
        }
      }
    },
    updateDefaultSearchField: {
      name: 'UpdateDefaultSearchField',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          DefaultSearchField: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          DefaultSearchField: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    updateServiceAccessPolicies: {
      name: 'UpdateServiceAccessPolicies',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          AccessPolicies: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          AccessPolicies: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    updateStemmingOptions: {
      name: 'UpdateStemmingOptions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          Stems: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Stems: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    updateStopwordOptions: {
      name: 'UpdateStopwordOptions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          Stopwords: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Stopwords: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    },
    updateSynonymOptions: {
      name: 'UpdateSynonymOptions',
      input: {
        type: 'structure',
        members: {
          DomainName: {
            required: true
          },
          Synonyms: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Synonyms: {
            type: 'structure',
            members: {
              Options: {
              },
              Status: {
                type: 'structure',
                members: {
                  CreationDate: {
                    type: 'timestamp'
                  },
                  UpdateDate: {
                    type: 'timestamp'
                  },
                  UpdateVersion: {
                    type: 'integer'
                  },
                  State: {
                  },
                  PendingDeletion: {
                    type: 'boolean'
                  }
                }
              }
            }
          }
        }
      }
    }
  },
  pagination: {
    describeDomains: {
      resultKey: 'DomainStatusList'
    },
    describeIndexFields: {
      resultKey: 'IndexFields'
    },
    describeRankExpressions: {
      resultKey: 'RankExpressions'
    }
  }
};
