/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'query',
  apiVersion: '2010-08-01',
  endpointPrefix: 'monitoring',
  resultWrapped: true,
  serviceAbbreviation: 'CloudWatch',
  serviceFullName: 'Amazon CloudWatch',
  signatureVersion: 'v2',
  timestampFormat: 'iso8601',
  operations: {
    deleteAlarms: {
      name: 'DeleteAlarms',
      input: {
        type: 'structure',
        members: {
          AlarmNames: {
            type: 'list',
            members: {
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    describeAlarmHistory: {
      name: 'DescribeAlarmHistory',
      input: {
        type: 'structure',
        members: {
          AlarmName: {
          },
          HistoryItemType: {
          },
          StartDate: {
            type: 'timestamp'
          },
          EndDate: {
            type: 'timestamp'
          },
          MaxRecords: {
            type: 'integer'
          },
          NextToken: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          AlarmHistoryItems: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                AlarmName: {
                },
                Timestamp: {
                  type: 'timestamp'
                },
                HistoryItemType: {
                },
                HistorySummary: {
                },
                HistoryData: {
                }
              }
            }
          },
          NextToken: {
          }
        }
      }
    },
    describeAlarms: {
      name: 'DescribeAlarms',
      input: {
        type: 'structure',
        members: {
          AlarmNames: {
            type: 'list',
            members: {
            }
          },
          AlarmNamePrefix: {
          },
          StateValue: {
          },
          ActionPrefix: {
          },
          MaxRecords: {
            type: 'integer'
          },
          NextToken: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          MetricAlarms: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                AlarmName: {
                },
                AlarmArn: {
                },
                AlarmDescription: {
                },
                AlarmConfigurationUpdatedTimestamp: {
                  type: 'timestamp'
                },
                ActionsEnabled: {
                  type: 'boolean'
                },
                OKActions: {
                  type: 'list',
                  members: {
                  }
                },
                AlarmActions: {
                  type: 'list',
                  members: {
                  }
                },
                InsufficientDataActions: {
                  type: 'list',
                  members: {
                  }
                },
                StateValue: {
                },
                StateReason: {
                },
                StateReasonData: {
                },
                StateUpdatedTimestamp: {
                  type: 'timestamp'
                },
                MetricName: {
                },
                Namespace: {
                },
                Statistic: {
                },
                Dimensions: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Name: {
                      },
                      Value: {
                      }
                    }
                  }
                },
                Period: {
                  type: 'integer'
                },
                Unit: {
                },
                EvaluationPeriods: {
                  type: 'integer'
                },
                Threshold: {
                  type: 'float'
                },
                ComparisonOperator: {
                }
              }
            }
          },
          NextToken: {
          }
        }
      }
    },
    describeAlarmsForMetric: {
      name: 'DescribeAlarmsForMetric',
      input: {
        type: 'structure',
        members: {
          MetricName: {
            required: true
          },
          Namespace: {
            required: true
          },
          Statistic: {
          },
          Dimensions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                Value: {
                  required: true
                }
              },
              order: [
                'Name',
                'Value'
              ]
            }
          },
          Period: {
            type: 'integer'
          },
          Unit: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          MetricAlarms: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                AlarmName: {
                },
                AlarmArn: {
                },
                AlarmDescription: {
                },
                AlarmConfigurationUpdatedTimestamp: {
                  type: 'timestamp'
                },
                ActionsEnabled: {
                  type: 'boolean'
                },
                OKActions: {
                  type: 'list',
                  members: {
                  }
                },
                AlarmActions: {
                  type: 'list',
                  members: {
                  }
                },
                InsufficientDataActions: {
                  type: 'list',
                  members: {
                  }
                },
                StateValue: {
                },
                StateReason: {
                },
                StateReasonData: {
                },
                StateUpdatedTimestamp: {
                  type: 'timestamp'
                },
                MetricName: {
                },
                Namespace: {
                },
                Statistic: {
                },
                Dimensions: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Name: {
                      },
                      Value: {
                      }
                    }
                  }
                },
                Period: {
                  type: 'integer'
                },
                Unit: {
                },
                EvaluationPeriods: {
                  type: 'integer'
                },
                Threshold: {
                  type: 'float'
                },
                ComparisonOperator: {
                }
              }
            }
          }
        }
      }
    },
    disableAlarmActions: {
      name: 'DisableAlarmActions',
      input: {
        type: 'structure',
        members: {
          AlarmNames: {
            type: 'list',
            members: {
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    enableAlarmActions: {
      name: 'EnableAlarmActions',
      input: {
        type: 'structure',
        members: {
          AlarmNames: {
            type: 'list',
            members: {
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    getMetricStatistics: {
      name: 'GetMetricStatistics',
      input: {
        type: 'structure',
        members: {
          Namespace: {
            required: true
          },
          MetricName: {
            required: true
          },
          Dimensions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                Value: {
                  required: true
                }
              },
              order: [
                'Name',
                'Value'
              ]
            }
          },
          StartTime: {
            type: 'timestamp',
            required: true
          },
          EndTime: {
            type: 'timestamp',
            required: true
          },
          Period: {
            type: 'integer',
            required: true
          },
          Statistics: {
            type: 'list',
            members: {
            },
            required: true
          },
          Unit: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Label: {
          },
          Datapoints: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Timestamp: {
                  type: 'timestamp'
                },
                SampleCount: {
                  type: 'float'
                },
                Average: {
                  type: 'float'
                },
                Sum: {
                  type: 'float'
                },
                Minimum: {
                  type: 'float'
                },
                Maximum: {
                  type: 'float'
                },
                Unit: {
                }
              }
            }
          }
        }
      }
    },
    listMetrics: {
      name: 'ListMetrics',
      input: {
        type: 'structure',
        members: {
          Namespace: {
          },
          MetricName: {
          },
          Dimensions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                Value: {
                }
              }
            }
          },
          NextToken: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Metrics: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Namespace: {
                },
                MetricName: {
                },
                Dimensions: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Name: {
                      },
                      Value: {
                      }
                    }
                  }
                }
              }
            }
          },
          NextToken: {
          }
        }
      }
    },
    putMetricAlarm: {
      name: 'PutMetricAlarm',
      input: {
        type: 'structure',
        members: {
          AlarmName: {
            required: true
          },
          AlarmDescription: {
          },
          ActionsEnabled: {
            type: 'boolean'
          },
          OKActions: {
            type: 'list',
            members: {
            }
          },
          AlarmActions: {
            type: 'list',
            members: {
            }
          },
          InsufficientDataActions: {
            type: 'list',
            members: {
            }
          },
          MetricName: {
            required: true
          },
          Namespace: {
            required: true
          },
          Statistic: {
            required: true
          },
          Dimensions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                Value: {
                  required: true
                }
              },
              order: [
                'Name',
                'Value'
              ]
            }
          },
          Period: {
            type: 'integer',
            required: true
          },
          Unit: {
          },
          EvaluationPeriods: {
            type: 'integer',
            required: true
          },
          Threshold: {
            type: 'float',
            required: true
          },
          ComparisonOperator: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    putMetricData: {
      name: 'PutMetricData',
      input: {
        type: 'structure',
        members: {
          Namespace: {
            required: true
          },
          MetricData: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                MetricName: {
                  required: true
                },
                Dimensions: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Name: {
                        required: true
                      },
                      Value: {
                        required: true
                      }
                    },
                    order: [
                      'Name',
                      'Value'
                    ]
                  }
                },
                Timestamp: {
                  type: 'timestamp'
                },
                Value: {
                  type: 'float'
                },
                StatisticValues: {
                  type: 'structure',
                  members: {
                    SampleCount: {
                      type: 'float',
                      required: true
                    },
                    Sum: {
                      type: 'float',
                      required: true
                    },
                    Minimum: {
                      type: 'float',
                      required: true
                    },
                    Maximum: {
                      type: 'float',
                      required: true
                    }
                  }
                },
                Unit: {
                }
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    setAlarmState: {
      name: 'SetAlarmState',
      input: {
        type: 'structure',
        members: {
          AlarmName: {
            required: true
          },
          StateValue: {
            required: true
          },
          StateReason: {
            required: true
          },
          StateReasonData: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    }
  },
  pagination: {
    describeAlarmHistory: {
      inputToken: 'NextToken',
      outputToken: 'NextToken',
      limitKey: 'MaxRecords',
      resultKey: 'AlarmHistoryItems'
    },
    describeAlarms: {
      inputToken: 'NextToken',
      outputToken: 'NextToken',
      limitKey: 'MaxRecords',
      resultKey: 'MetricAlarms'
    },
    describeAlarmsForMetric: {
      resultKey: 'MetricAlarms'
    },
    listMetrics: {
      inputToken: 'NextToken',
      outputToken: 'NextToken',
      resultKey: 'Metrics'
    }
  }
};
