/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'rest-json',
  apiVersion: '2012-09-25',
  endpointPrefix: 'elastictranscoder',
  serviceFullName: 'Amazon Elastic Transcoder',
  signatureVersion: 'v4',
  timestampFormat: 'iso8601',
  operations: {
    cancelJob: {
      name: 'CancelJob',
      http: {
        method: 'DELETE',
        uri: '/2012-09-25/jobs/{Id}'
      },
      input: {
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    createJob: {
      name: 'CreateJob',
      http: {
        method: 'POST',
        uri: '/2012-09-25/jobs'
      },
      input: {
        payload: [
          'PipelineId',
          'Input',
          'Output',
          'Outputs',
          'OutputKeyPrefix',
          'Playlists'
        ],
        type: 'structure',
        members: {
          PipelineId: {
          },
          Input: {
            type: 'structure',
            members: {
              Key: {
              },
              FrameRate: {
              },
              Resolution: {
              },
              AspectRatio: {
              },
              Interlaced: {
              },
              Container: {
              }
            }
          },
          Output: {
            type: 'structure',
            members: {
              Key: {
              },
              ThumbnailPattern: {
              },
              Rotate: {
              },
              PresetId: {
              },
              SegmentDuration: {
              },
              Watermarks: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    PresetWatermarkId: {
                    },
                    InputKey: {
                    }
                  }
                }
              },
              AlbumArt: {
                type: 'structure',
                members: {
                  MergePolicy: {
                  },
                  Artwork: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        InputKey: {
                        },
                        MaxWidth: {
                        },
                        MaxHeight: {
                        },
                        SizingPolicy: {
                        },
                        PaddingPolicy: {
                        },
                        AlbumArtFormat: {
                        }
                      }
                    }
                  }
                }
              },
              Composition: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    TimeSpan: {
                      type: 'structure',
                      members: {
                        StartTime: {
                        },
                        Duration: {
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          Outputs: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Key: {
                },
                ThumbnailPattern: {
                },
                Rotate: {
                },
                PresetId: {
                },
                SegmentDuration: {
                },
                Watermarks: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      PresetWatermarkId: {
                      },
                      InputKey: {
                      }
                    }
                  }
                },
                AlbumArt: {
                  type: 'structure',
                  members: {
                    MergePolicy: {
                    },
                    Artwork: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          InputKey: {
                          },
                          MaxWidth: {
                          },
                          MaxHeight: {
                          },
                          SizingPolicy: {
                          },
                          PaddingPolicy: {
                          },
                          AlbumArtFormat: {
                          }
                        }
                      }
                    }
                  }
                },
                Composition: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      TimeSpan: {
                        type: 'structure',
                        members: {
                          StartTime: {
                          },
                          Duration: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          OutputKeyPrefix: {
          },
          Playlists: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                },
                Format: {
                },
                OutputKeys: {
                  type: 'list',
                  members: {
                  }
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Job: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              PipelineId: {
              },
              Input: {
                type: 'structure',
                members: {
                  Key: {
                  },
                  FrameRate: {
                  },
                  Resolution: {
                  },
                  AspectRatio: {
                  },
                  Interlaced: {
                  },
                  Container: {
                  }
                }
              },
              Output: {
                type: 'structure',
                members: {
                  Id: {
                  },
                  Key: {
                  },
                  ThumbnailPattern: {
                  },
                  Rotate: {
                  },
                  PresetId: {
                  },
                  SegmentDuration: {
                  },
                  Status: {
                  },
                  StatusDetail: {
                  },
                  Duration: {
                    type: 'integer'
                  },
                  Width: {
                    type: 'integer'
                  },
                  Height: {
                    type: 'integer'
                  },
                  Watermarks: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        PresetWatermarkId: {
                        },
                        InputKey: {
                        }
                      }
                    }
                  },
                  AlbumArt: {
                    type: 'structure',
                    members: {
                      MergePolicy: {
                      },
                      Artwork: {
                        type: 'list',
                        members: {
                          type: 'structure',
                          members: {
                            InputKey: {
                            },
                            MaxWidth: {
                            },
                            MaxHeight: {
                            },
                            SizingPolicy: {
                            },
                            PaddingPolicy: {
                            },
                            AlbumArtFormat: {
                            }
                          }
                        }
                      }
                    }
                  },
                  Composition: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        TimeSpan: {
                          type: 'structure',
                          members: {
                            StartTime: {
                            },
                            Duration: {
                            }
                          }
                        }
                      }
                    }
                  }
                }
              },
              Outputs: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Id: {
                    },
                    Key: {
                    },
                    ThumbnailPattern: {
                    },
                    Rotate: {
                    },
                    PresetId: {
                    },
                    SegmentDuration: {
                    },
                    Status: {
                    },
                    StatusDetail: {
                    },
                    Duration: {
                      type: 'integer'
                    },
                    Width: {
                      type: 'integer'
                    },
                    Height: {
                      type: 'integer'
                    },
                    Watermarks: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          PresetWatermarkId: {
                          },
                          InputKey: {
                          }
                        }
                      }
                    },
                    AlbumArt: {
                      type: 'structure',
                      members: {
                        MergePolicy: {
                        },
                        Artwork: {
                          type: 'list',
                          members: {
                            type: 'structure',
                            members: {
                              InputKey: {
                              },
                              MaxWidth: {
                              },
                              MaxHeight: {
                              },
                              SizingPolicy: {
                              },
                              PaddingPolicy: {
                              },
                              AlbumArtFormat: {
                              }
                            }
                          }
                        }
                      }
                    },
                    Composition: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          TimeSpan: {
                            type: 'structure',
                            members: {
                              StartTime: {
                              },
                              Duration: {
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              },
              OutputKeyPrefix: {
              },
              Playlists: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Name: {
                    },
                    Format: {
                    },
                    OutputKeys: {
                      type: 'list',
                      members: {
                      }
                    },
                    Status: {
                    },
                    StatusDetail: {
                    }
                  }
                }
              },
              Status: {
              }
            }
          }
        }
      }
    },
    createPipeline: {
      name: 'CreatePipeline',
      http: {
        method: 'POST',
        uri: '/2012-09-25/pipelines'
      },
      input: {
        payload: [
          'Name',
          'InputBucket',
          'OutputBucket',
          'Role',
          'Notifications',
          'ContentConfig',
          'ThumbnailConfig'
        ],
        type: 'structure',
        members: {
          Name: {
          },
          InputBucket: {
          },
          OutputBucket: {
          },
          Role: {
          },
          Notifications: {
            type: 'structure',
            members: {
              Progressing: {
              },
              Completed: {
              },
              Warning: {
              },
              Error: {
              }
            }
          },
          ContentConfig: {
            type: 'structure',
            members: {
              Bucket: {
              },
              StorageClass: {
              },
              Permissions: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    GranteeType: {
                    },
                    Grantee: {
                    },
                    Access: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                }
              }
            }
          },
          ThumbnailConfig: {
            type: 'structure',
            members: {
              Bucket: {
              },
              StorageClass: {
              },
              Permissions: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    GranteeType: {
                    },
                    Grantee: {
                    },
                    Access: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Pipeline: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Status: {
              },
              InputBucket: {
              },
              OutputBucket: {
              },
              Role: {
              },
              Notifications: {
                type: 'structure',
                members: {
                  Progressing: {
                  },
                  Completed: {
                  },
                  Warning: {
                  },
                  Error: {
                  }
                }
              },
              ContentConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              },
              ThumbnailConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    createPreset: {
      name: 'CreatePreset',
      http: {
        method: 'POST',
        uri: '/2012-09-25/presets'
      },
      input: {
        payload: [
          'Name',
          'Description',
          'Container',
          'Video',
          'Audio',
          'Thumbnails'
        ],
        type: 'structure',
        members: {
          Name: {
          },
          Description: {
          },
          Container: {
          },
          Video: {
            type: 'structure',
            members: {
              Codec: {
              },
              CodecOptions: {
                type: 'map',
                keys: {
                },
                members: {
                }
              },
              KeyframesMaxDist: {
              },
              FixedGOP: {
              },
              BitRate: {
              },
              FrameRate: {
              },
              MaxFrameRate: {
              },
              Resolution: {
              },
              AspectRatio: {
              },
              MaxWidth: {
              },
              MaxHeight: {
              },
              DisplayAspectRatio: {
              },
              SizingPolicy: {
              },
              PaddingPolicy: {
              },
              Watermarks: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Id: {
                    },
                    MaxWidth: {
                    },
                    MaxHeight: {
                    },
                    SizingPolicy: {
                    },
                    HorizontalAlign: {
                    },
                    HorizontalOffset: {
                    },
                    VerticalAlign: {
                    },
                    VerticalOffset: {
                    },
                    Opacity: {
                    },
                    Target: {
                    }
                  }
                }
              }
            }
          },
          Audio: {
            type: 'structure',
            members: {
              Codec: {
              },
              SampleRate: {
              },
              BitRate: {
              },
              Channels: {
              },
              CodecOptions: {
                type: 'structure',
                members: {
                  Profile: {
                  }
                }
              }
            }
          },
          Thumbnails: {
            type: 'structure',
            members: {
              Format: {
              },
              Interval: {
              },
              Resolution: {
              },
              AspectRatio: {
              },
              MaxWidth: {
              },
              MaxHeight: {
              },
              SizingPolicy: {
              },
              PaddingPolicy: {
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Preset: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Description: {
              },
              Container: {
              },
              Audio: {
                type: 'structure',
                members: {
                  Codec: {
                  },
                  SampleRate: {
                  },
                  BitRate: {
                  },
                  Channels: {
                  },
                  CodecOptions: {
                    type: 'structure',
                    members: {
                      Profile: {
                      }
                    }
                  }
                }
              },
              Video: {
                type: 'structure',
                members: {
                  Codec: {
                  },
                  CodecOptions: {
                    type: 'map',
                    keys: {
                    },
                    members: {
                    }
                  },
                  KeyframesMaxDist: {
                  },
                  FixedGOP: {
                  },
                  BitRate: {
                  },
                  FrameRate: {
                  },
                  MaxFrameRate: {
                  },
                  Resolution: {
                  },
                  AspectRatio: {
                  },
                  MaxWidth: {
                  },
                  MaxHeight: {
                  },
                  DisplayAspectRatio: {
                  },
                  SizingPolicy: {
                  },
                  PaddingPolicy: {
                  },
                  Watermarks: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        Id: {
                        },
                        MaxWidth: {
                        },
                        MaxHeight: {
                        },
                        SizingPolicy: {
                        },
                        HorizontalAlign: {
                        },
                        HorizontalOffset: {
                        },
                        VerticalAlign: {
                        },
                        VerticalOffset: {
                        },
                        Opacity: {
                        },
                        Target: {
                        }
                      }
                    }
                  }
                }
              },
              Thumbnails: {
                type: 'structure',
                members: {
                  Format: {
                  },
                  Interval: {
                  },
                  Resolution: {
                  },
                  AspectRatio: {
                  },
                  MaxWidth: {
                  },
                  MaxHeight: {
                  },
                  SizingPolicy: {
                  },
                  PaddingPolicy: {
                  }
                }
              },
              Type: {
              }
            }
          },
          Warning: {
          }
        }
      }
    },
    deletePipeline: {
      name: 'DeletePipeline',
      http: {
        method: 'DELETE',
        uri: '/2012-09-25/pipelines/{Id}'
      },
      input: {
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    deletePreset: {
      name: 'DeletePreset',
      http: {
        method: 'DELETE',
        uri: '/2012-09-25/presets/{Id}'
      },
      input: {
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    listJobsByPipeline: {
      name: 'ListJobsByPipeline',
      http: {
        method: 'GET',
        uri: '/2012-09-25/jobsByPipeline/{PipelineId}?Ascending={Ascending}&PageToken={PageToken}'
      },
      input: {
        type: 'structure',
        members: {
          PipelineId: {
            location: 'uri'
          },
          Ascending: {
            location: 'uri'
          },
          PageToken: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Jobs: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Arn: {
                },
                PipelineId: {
                },
                Input: {
                  type: 'structure',
                  members: {
                    Key: {
                    },
                    FrameRate: {
                    },
                    Resolution: {
                    },
                    AspectRatio: {
                    },
                    Interlaced: {
                    },
                    Container: {
                    }
                  }
                },
                Output: {
                  type: 'structure',
                  members: {
                    Id: {
                    },
                    Key: {
                    },
                    ThumbnailPattern: {
                    },
                    Rotate: {
                    },
                    PresetId: {
                    },
                    SegmentDuration: {
                    },
                    Status: {
                    },
                    StatusDetail: {
                    },
                    Duration: {
                      type: 'integer'
                    },
                    Width: {
                      type: 'integer'
                    },
                    Height: {
                      type: 'integer'
                    },
                    Watermarks: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          PresetWatermarkId: {
                          },
                          InputKey: {
                          }
                        }
                      }
                    },
                    AlbumArt: {
                      type: 'structure',
                      members: {
                        MergePolicy: {
                        },
                        Artwork: {
                          type: 'list',
                          members: {
                            type: 'structure',
                            members: {
                              InputKey: {
                              },
                              MaxWidth: {
                              },
                              MaxHeight: {
                              },
                              SizingPolicy: {
                              },
                              PaddingPolicy: {
                              },
                              AlbumArtFormat: {
                              }
                            }
                          }
                        }
                      }
                    },
                    Composition: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          TimeSpan: {
                            type: 'structure',
                            members: {
                              StartTime: {
                              },
                              Duration: {
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                },
                Outputs: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Id: {
                      },
                      Key: {
                      },
                      ThumbnailPattern: {
                      },
                      Rotate: {
                      },
                      PresetId: {
                      },
                      SegmentDuration: {
                      },
                      Status: {
                      },
                      StatusDetail: {
                      },
                      Duration: {
                        type: 'integer'
                      },
                      Width: {
                        type: 'integer'
                      },
                      Height: {
                        type: 'integer'
                      },
                      Watermarks: {
                        type: 'list',
                        members: {
                          type: 'structure',
                          members: {
                            PresetWatermarkId: {
                            },
                            InputKey: {
                            }
                          }
                        }
                      },
                      AlbumArt: {
                        type: 'structure',
                        members: {
                          MergePolicy: {
                          },
                          Artwork: {
                            type: 'list',
                            members: {
                              type: 'structure',
                              members: {
                                InputKey: {
                                },
                                MaxWidth: {
                                },
                                MaxHeight: {
                                },
                                SizingPolicy: {
                                },
                                PaddingPolicy: {
                                },
                                AlbumArtFormat: {
                                }
                              }
                            }
                          }
                        }
                      },
                      Composition: {
                        type: 'list',
                        members: {
                          type: 'structure',
                          members: {
                            TimeSpan: {
                              type: 'structure',
                              members: {
                                StartTime: {
                                },
                                Duration: {
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                },
                OutputKeyPrefix: {
                },
                Playlists: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Name: {
                      },
                      Format: {
                      },
                      OutputKeys: {
                        type: 'list',
                        members: {
                        }
                      },
                      Status: {
                      },
                      StatusDetail: {
                      }
                    }
                  }
                },
                Status: {
                }
              }
            }
          },
          NextPageToken: {
          }
        }
      }
    },
    listJobsByStatus: {
      name: 'ListJobsByStatus',
      http: {
        method: 'GET',
        uri: '/2012-09-25/jobsByStatus/{Status}?Ascending={Ascending}&PageToken={PageToken}'
      },
      input: {
        type: 'structure',
        members: {
          Status: {
            location: 'uri'
          },
          Ascending: {
            location: 'uri'
          },
          PageToken: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Jobs: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Arn: {
                },
                PipelineId: {
                },
                Input: {
                  type: 'structure',
                  members: {
                    Key: {
                    },
                    FrameRate: {
                    },
                    Resolution: {
                    },
                    AspectRatio: {
                    },
                    Interlaced: {
                    },
                    Container: {
                    }
                  }
                },
                Output: {
                  type: 'structure',
                  members: {
                    Id: {
                    },
                    Key: {
                    },
                    ThumbnailPattern: {
                    },
                    Rotate: {
                    },
                    PresetId: {
                    },
                    SegmentDuration: {
                    },
                    Status: {
                    },
                    StatusDetail: {
                    },
                    Duration: {
                      type: 'integer'
                    },
                    Width: {
                      type: 'integer'
                    },
                    Height: {
                      type: 'integer'
                    },
                    Watermarks: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          PresetWatermarkId: {
                          },
                          InputKey: {
                          }
                        }
                      }
                    },
                    AlbumArt: {
                      type: 'structure',
                      members: {
                        MergePolicy: {
                        },
                        Artwork: {
                          type: 'list',
                          members: {
                            type: 'structure',
                            members: {
                              InputKey: {
                              },
                              MaxWidth: {
                              },
                              MaxHeight: {
                              },
                              SizingPolicy: {
                              },
                              PaddingPolicy: {
                              },
                              AlbumArtFormat: {
                              }
                            }
                          }
                        }
                      }
                    },
                    Composition: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          TimeSpan: {
                            type: 'structure',
                            members: {
                              StartTime: {
                              },
                              Duration: {
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                },
                Outputs: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Id: {
                      },
                      Key: {
                      },
                      ThumbnailPattern: {
                      },
                      Rotate: {
                      },
                      PresetId: {
                      },
                      SegmentDuration: {
                      },
                      Status: {
                      },
                      StatusDetail: {
                      },
                      Duration: {
                        type: 'integer'
                      },
                      Width: {
                        type: 'integer'
                      },
                      Height: {
                        type: 'integer'
                      },
                      Watermarks: {
                        type: 'list',
                        members: {
                          type: 'structure',
                          members: {
                            PresetWatermarkId: {
                            },
                            InputKey: {
                            }
                          }
                        }
                      },
                      AlbumArt: {
                        type: 'structure',
                        members: {
                          MergePolicy: {
                          },
                          Artwork: {
                            type: 'list',
                            members: {
                              type: 'structure',
                              members: {
                                InputKey: {
                                },
                                MaxWidth: {
                                },
                                MaxHeight: {
                                },
                                SizingPolicy: {
                                },
                                PaddingPolicy: {
                                },
                                AlbumArtFormat: {
                                }
                              }
                            }
                          }
                        }
                      },
                      Composition: {
                        type: 'list',
                        members: {
                          type: 'structure',
                          members: {
                            TimeSpan: {
                              type: 'structure',
                              members: {
                                StartTime: {
                                },
                                Duration: {
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                },
                OutputKeyPrefix: {
                },
                Playlists: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      Name: {
                      },
                      Format: {
                      },
                      OutputKeys: {
                        type: 'list',
                        members: {
                        }
                      },
                      Status: {
                      },
                      StatusDetail: {
                      }
                    }
                  }
                },
                Status: {
                }
              }
            }
          },
          NextPageToken: {
          }
        }
      }
    },
    listPipelines: {
      name: 'ListPipelines',
      http: {
        method: 'GET',
        uri: '/2012-09-25/pipelines?Ascending={Ascending}&PageToken={PageToken}'
      },
      input: {
        type: 'structure',
        members: {
          Ascending: {
            location: 'uri'
          },
          PageToken: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Pipelines: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Arn: {
                },
                Name: {
                },
                Status: {
                },
                InputBucket: {
                },
                OutputBucket: {
                },
                Role: {
                },
                Notifications: {
                  type: 'structure',
                  members: {
                    Progressing: {
                    },
                    Completed: {
                    },
                    Warning: {
                    },
                    Error: {
                    }
                  }
                },
                ContentConfig: {
                  type: 'structure',
                  members: {
                    Bucket: {
                    },
                    StorageClass: {
                    },
                    Permissions: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          GranteeType: {
                          },
                          Grantee: {
                          },
                          Access: {
                            type: 'list',
                            members: {
                            }
                          }
                        }
                      }
                    }
                  }
                },
                ThumbnailConfig: {
                  type: 'structure',
                  members: {
                    Bucket: {
                    },
                    StorageClass: {
                    },
                    Permissions: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          GranteeType: {
                          },
                          Grantee: {
                          },
                          Access: {
                            type: 'list',
                            members: {
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          NextPageToken: {
          }
        }
      }
    },
    listPresets: {
      name: 'ListPresets',
      http: {
        method: 'GET',
        uri: '/2012-09-25/presets?Ascending={Ascending}&PageToken={PageToken}'
      },
      input: {
        type: 'structure',
        members: {
          Ascending: {
            location: 'uri'
          },
          PageToken: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Presets: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Arn: {
                },
                Name: {
                },
                Description: {
                },
                Container: {
                },
                Audio: {
                  type: 'structure',
                  members: {
                    Codec: {
                    },
                    SampleRate: {
                    },
                    BitRate: {
                    },
                    Channels: {
                    },
                    CodecOptions: {
                      type: 'structure',
                      members: {
                        Profile: {
                        }
                      }
                    }
                  }
                },
                Video: {
                  type: 'structure',
                  members: {
                    Codec: {
                    },
                    CodecOptions: {
                      type: 'map',
                      keys: {
                      },
                      members: {
                      }
                    },
                    KeyframesMaxDist: {
                    },
                    FixedGOP: {
                    },
                    BitRate: {
                    },
                    FrameRate: {
                    },
                    MaxFrameRate: {
                    },
                    Resolution: {
                    },
                    AspectRatio: {
                    },
                    MaxWidth: {
                    },
                    MaxHeight: {
                    },
                    DisplayAspectRatio: {
                    },
                    SizingPolicy: {
                    },
                    PaddingPolicy: {
                    },
                    Watermarks: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          Id: {
                          },
                          MaxWidth: {
                          },
                          MaxHeight: {
                          },
                          SizingPolicy: {
                          },
                          HorizontalAlign: {
                          },
                          HorizontalOffset: {
                          },
                          VerticalAlign: {
                          },
                          VerticalOffset: {
                          },
                          Opacity: {
                          },
                          Target: {
                          }
                        }
                      }
                    }
                  }
                },
                Thumbnails: {
                  type: 'structure',
                  members: {
                    Format: {
                    },
                    Interval: {
                    },
                    Resolution: {
                    },
                    AspectRatio: {
                    },
                    MaxWidth: {
                    },
                    MaxHeight: {
                    },
                    SizingPolicy: {
                    },
                    PaddingPolicy: {
                    }
                  }
                },
                Type: {
                }
              }
            }
          },
          NextPageToken: {
          }
        }
      }
    },
    readJob: {
      name: 'ReadJob',
      http: {
        method: 'GET',
        uri: '/2012-09-25/jobs/{Id}'
      },
      input: {
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Job: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              PipelineId: {
              },
              Input: {
                type: 'structure',
                members: {
                  Key: {
                  },
                  FrameRate: {
                  },
                  Resolution: {
                  },
                  AspectRatio: {
                  },
                  Interlaced: {
                  },
                  Container: {
                  }
                }
              },
              Output: {
                type: 'structure',
                members: {
                  Id: {
                  },
                  Key: {
                  },
                  ThumbnailPattern: {
                  },
                  Rotate: {
                  },
                  PresetId: {
                  },
                  SegmentDuration: {
                  },
                  Status: {
                  },
                  StatusDetail: {
                  },
                  Duration: {
                    type: 'integer'
                  },
                  Width: {
                    type: 'integer'
                  },
                  Height: {
                    type: 'integer'
                  },
                  Watermarks: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        PresetWatermarkId: {
                        },
                        InputKey: {
                        }
                      }
                    }
                  },
                  AlbumArt: {
                    type: 'structure',
                    members: {
                      MergePolicy: {
                      },
                      Artwork: {
                        type: 'list',
                        members: {
                          type: 'structure',
                          members: {
                            InputKey: {
                            },
                            MaxWidth: {
                            },
                            MaxHeight: {
                            },
                            SizingPolicy: {
                            },
                            PaddingPolicy: {
                            },
                            AlbumArtFormat: {
                            }
                          }
                        }
                      }
                    }
                  },
                  Composition: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        TimeSpan: {
                          type: 'structure',
                          members: {
                            StartTime: {
                            },
                            Duration: {
                            }
                          }
                        }
                      }
                    }
                  }
                }
              },
              Outputs: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Id: {
                    },
                    Key: {
                    },
                    ThumbnailPattern: {
                    },
                    Rotate: {
                    },
                    PresetId: {
                    },
                    SegmentDuration: {
                    },
                    Status: {
                    },
                    StatusDetail: {
                    },
                    Duration: {
                      type: 'integer'
                    },
                    Width: {
                      type: 'integer'
                    },
                    Height: {
                      type: 'integer'
                    },
                    Watermarks: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          PresetWatermarkId: {
                          },
                          InputKey: {
                          }
                        }
                      }
                    },
                    AlbumArt: {
                      type: 'structure',
                      members: {
                        MergePolicy: {
                        },
                        Artwork: {
                          type: 'list',
                          members: {
                            type: 'structure',
                            members: {
                              InputKey: {
                              },
                              MaxWidth: {
                              },
                              MaxHeight: {
                              },
                              SizingPolicy: {
                              },
                              PaddingPolicy: {
                              },
                              AlbumArtFormat: {
                              }
                            }
                          }
                        }
                      }
                    },
                    Composition: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          TimeSpan: {
                            type: 'structure',
                            members: {
                              StartTime: {
                              },
                              Duration: {
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              },
              OutputKeyPrefix: {
              },
              Playlists: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Name: {
                    },
                    Format: {
                    },
                    OutputKeys: {
                      type: 'list',
                      members: {
                      }
                    },
                    Status: {
                    },
                    StatusDetail: {
                    }
                  }
                }
              },
              Status: {
              }
            }
          }
        }
      }
    },
    readPipeline: {
      name: 'ReadPipeline',
      http: {
        method: 'GET',
        uri: '/2012-09-25/pipelines/{Id}'
      },
      input: {
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Pipeline: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Status: {
              },
              InputBucket: {
              },
              OutputBucket: {
              },
              Role: {
              },
              Notifications: {
                type: 'structure',
                members: {
                  Progressing: {
                  },
                  Completed: {
                  },
                  Warning: {
                  },
                  Error: {
                  }
                }
              },
              ContentConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              },
              ThumbnailConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    readPreset: {
      name: 'ReadPreset',
      http: {
        method: 'GET',
        uri: '/2012-09-25/presets/{Id}'
      },
      input: {
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Preset: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Description: {
              },
              Container: {
              },
              Audio: {
                type: 'structure',
                members: {
                  Codec: {
                  },
                  SampleRate: {
                  },
                  BitRate: {
                  },
                  Channels: {
                  },
                  CodecOptions: {
                    type: 'structure',
                    members: {
                      Profile: {
                      }
                    }
                  }
                }
              },
              Video: {
                type: 'structure',
                members: {
                  Codec: {
                  },
                  CodecOptions: {
                    type: 'map',
                    keys: {
                    },
                    members: {
                    }
                  },
                  KeyframesMaxDist: {
                  },
                  FixedGOP: {
                  },
                  BitRate: {
                  },
                  FrameRate: {
                  },
                  MaxFrameRate: {
                  },
                  Resolution: {
                  },
                  AspectRatio: {
                  },
                  MaxWidth: {
                  },
                  MaxHeight: {
                  },
                  DisplayAspectRatio: {
                  },
                  SizingPolicy: {
                  },
                  PaddingPolicy: {
                  },
                  Watermarks: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        Id: {
                        },
                        MaxWidth: {
                        },
                        MaxHeight: {
                        },
                        SizingPolicy: {
                        },
                        HorizontalAlign: {
                        },
                        HorizontalOffset: {
                        },
                        VerticalAlign: {
                        },
                        VerticalOffset: {
                        },
                        Opacity: {
                        },
                        Target: {
                        }
                      }
                    }
                  }
                }
              },
              Thumbnails: {
                type: 'structure',
                members: {
                  Format: {
                  },
                  Interval: {
                  },
                  Resolution: {
                  },
                  AspectRatio: {
                  },
                  MaxWidth: {
                  },
                  MaxHeight: {
                  },
                  SizingPolicy: {
                  },
                  PaddingPolicy: {
                  }
                }
              },
              Type: {
              }
            }
          }
        }
      }
    },
    testRole: {
      name: 'TestRole',
      http: {
        method: 'POST',
        uri: '/2012-09-25/roleTests'
      },
      input: {
        payload: [
          'Role',
          'InputBucket',
          'OutputBucket',
          'Topics'
        ],
        type: 'structure',
        members: {
          Role: {
          },
          InputBucket: {
          },
          OutputBucket: {
          },
          Topics: {
            type: 'list',
            members: {
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Success: {
          },
          Messages: {
            type: 'list',
            members: {
            }
          }
        }
      }
    },
    updatePipeline: {
      name: 'UpdatePipeline',
      http: {
        method: 'PUT',
        uri: '/2012-09-25/pipelines/{Id}'
      },
      input: {
        payload: [
          'Name',
          'InputBucket',
          'Role',
          'Notifications',
          'ContentConfig',
          'ThumbnailConfig'
        ],
        type: 'structure',
        members: {
          Id: {
            required: true,
            location: 'uri'
          },
          Name: {
          },
          InputBucket: {
          },
          Role: {
          },
          Notifications: {
            type: 'structure',
            members: {
              Progressing: {
              },
              Completed: {
              },
              Warning: {
              },
              Error: {
              }
            }
          },
          ContentConfig: {
            type: 'structure',
            members: {
              Bucket: {
              },
              StorageClass: {
              },
              Permissions: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    GranteeType: {
                    },
                    Grantee: {
                    },
                    Access: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                }
              }
            }
          },
          ThumbnailConfig: {
            type: 'structure',
            members: {
              Bucket: {
              },
              StorageClass: {
              },
              Permissions: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    GranteeType: {
                    },
                    Grantee: {
                    },
                    Access: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Pipeline: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Status: {
              },
              InputBucket: {
              },
              OutputBucket: {
              },
              Role: {
              },
              Notifications: {
                type: 'structure',
                members: {
                  Progressing: {
                  },
                  Completed: {
                  },
                  Warning: {
                  },
                  Error: {
                  }
                }
              },
              ContentConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              },
              ThumbnailConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    updatePipelineNotifications: {
      name: 'UpdatePipelineNotifications',
      http: {
        method: 'POST',
        uri: '/2012-09-25/pipelines/{Id}/notifications'
      },
      input: {
        payload: [
          'Notifications'
        ],
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          },
          Notifications: {
            type: 'structure',
            members: {
              Progressing: {
              },
              Completed: {
              },
              Warning: {
              },
              Error: {
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Pipeline: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Status: {
              },
              InputBucket: {
              },
              OutputBucket: {
              },
              Role: {
              },
              Notifications: {
                type: 'structure',
                members: {
                  Progressing: {
                  },
                  Completed: {
                  },
                  Warning: {
                  },
                  Error: {
                  }
                }
              },
              ContentConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              },
              ThumbnailConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    updatePipelineStatus: {
      name: 'UpdatePipelineStatus',
      http: {
        method: 'POST',
        uri: '/2012-09-25/pipelines/{Id}/status'
      },
      input: {
        payload: [
          'Status'
        ],
        type: 'structure',
        members: {
          Id: {
            location: 'uri'
          },
          Status: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Pipeline: {
            type: 'structure',
            members: {
              Id: {
              },
              Arn: {
              },
              Name: {
              },
              Status: {
              },
              InputBucket: {
              },
              OutputBucket: {
              },
              Role: {
              },
              Notifications: {
                type: 'structure',
                members: {
                  Progressing: {
                  },
                  Completed: {
                  },
                  Warning: {
                  },
                  Error: {
                  }
                }
              },
              ContentConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              },
              ThumbnailConfig: {
                type: 'structure',
                members: {
                  Bucket: {
                  },
                  StorageClass: {
                  },
                  Permissions: {
                    type: 'list',
                    members: {
                      type: 'structure',
                      members: {
                        GranteeType: {
                        },
                        Grantee: {
                        },
                        Access: {
                          type: 'list',
                          members: {
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  },
  pagination: {
    listJobsByPipeline: {
      inputToken: 'PageToken',
      outputToken: 'NextPageToken',
      resultKey: 'Jobs'
    },
    listJobsByStatus: {
      inputToken: 'PageToken',
      outputToken: 'NextPageToken',
      resultKey: 'Jobs'
    },
    listPipelines: {
      resultKey: 'Pipelines'
    },
    listPresets: {
      resultKey: 'Presets'
    }
  }
};
