/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'json',
  apiVersion: '2009-03-31',
  endpointPrefix: 'elasticmapreduce',
  jsonVersion: '1.1',
  serviceAbbreviation: 'Amazon EMR',
  serviceFullName: 'Amazon Elastic MapReduce',
  signatureVersion: 'v4',
  targetPrefix: 'ElasticMapReduce',
  timestampFormat: 'unixTimestamp',
  operations: {
    addInstanceGroups: {
      name: 'AddInstanceGroups',
      input: {
        type: 'structure',
        members: {
          InstanceGroups: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                },
                Market: {
                },
                InstanceRole: {
                  required: true
                },
                BidPrice: {
                },
                InstanceType: {
                  required: true
                },
                InstanceCount: {
                  type: 'integer',
                  required: true
                }
              }
            },
            required: true
          },
          JobFlowId: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          JobFlowId: {
          },
          InstanceGroupIds: {
            type: 'list',
            members: {
            }
          }
        }
      }
    },
    addJobFlowSteps: {
      name: 'AddJobFlowSteps',
      input: {
        type: 'structure',
        members: {
          JobFlowId: {
            required: true
          },
          Steps: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                ActionOnFailure: {
                },
                HadoopJarStep: {
                  type: 'structure',
                  members: {
                    Properties: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          Key: {
                          },
                          Value: {
                          }
                        }
                      }
                    },
                    Jar: {
                      required: true
                    },
                    MainClass: {
                    },
                    Args: {
                      type: 'list',
                      members: {
                      }
                    }
                  },
                  required: true
                }
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          StepIds: {
            type: 'list',
            members: {
            }
          }
        }
      }
    },
    addTags: {
      name: 'AddTags',
      input: {
        type: 'structure',
        members: {
          ResourceId: {
          },
          Tags: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Key: {
                },
                Value: {
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    describeCluster: {
      name: 'DescribeCluster',
      input: {
        type: 'structure',
        members: {
          ClusterId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Cluster: {
            type: 'structure',
            members: {
              Id: {
              },
              Name: {
              },
              Status: {
                type: 'structure',
                members: {
                  State: {
                  },
                  StateChangeReason: {
                    type: 'structure',
                    members: {
                      Code: {
                      },
                      Message: {
                      }
                    }
                  },
                  Timeline: {
                    type: 'structure',
                    members: {
                      CreationDateTime: {
                        type: 'timestamp'
                      },
                      ReadyDateTime: {
                        type: 'timestamp'
                      },
                      EndDateTime: {
                        type: 'timestamp'
                      }
                    }
                  }
                }
              },
              Ec2InstanceAttributes: {
                type: 'structure',
                members: {
                  Ec2KeyName: {
                  },
                  Ec2SubnetId: {
                  },
                  Ec2AvailabilityZone: {
                  },
                  IamInstanceProfile: {
                  }
                }
              },
              LogUri: {
              },
              RequestedAmiVersion: {
              },
              RunningAmiVersion: {
              },
              AutoTerminate: {
                type: 'boolean'
              },
              TerminationProtected: {
                type: 'boolean'
              },
              VisibleToAllUsers: {
                type: 'boolean'
              },
              Applications: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Name: {
                    },
                    Version: {
                    },
                    Args: {
                      type: 'list',
                      members: {
                      }
                    },
                    AdditionalInfo: {
                      type: 'map',
                      keys: {
                      },
                      members: {
                      }
                    }
                  }
                }
              },
              Tags: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Key: {
                    },
                    Value: {
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    describeJobFlows: {
      name: 'DescribeJobFlows',
      input: {
        type: 'structure',
        members: {
          CreatedAfter: {
            type: 'timestamp'
          },
          CreatedBefore: {
            type: 'timestamp'
          },
          JobFlowIds: {
            type: 'list',
            members: {
            }
          },
          JobFlowStates: {
            type: 'list',
            members: {
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          JobFlows: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                JobFlowId: {
                },
                Name: {
                },
                LogUri: {
                },
                AmiVersion: {
                },
                ExecutionStatusDetail: {
                  type: 'structure',
                  members: {
                    State: {
                    },
                    CreationDateTime: {
                      type: 'timestamp'
                    },
                    StartDateTime: {
                      type: 'timestamp'
                    },
                    ReadyDateTime: {
                      type: 'timestamp'
                    },
                    EndDateTime: {
                      type: 'timestamp'
                    },
                    LastStateChangeReason: {
                    }
                  }
                },
                Instances: {
                  type: 'structure',
                  members: {
                    MasterInstanceType: {
                    },
                    MasterPublicDnsName: {
                    },
                    MasterInstanceId: {
                    },
                    SlaveInstanceType: {
                    },
                    InstanceCount: {
                      type: 'integer'
                    },
                    InstanceGroups: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          InstanceGroupId: {
                          },
                          Name: {
                          },
                          Market: {
                          },
                          InstanceRole: {
                          },
                          BidPrice: {
                          },
                          InstanceType: {
                          },
                          InstanceRequestCount: {
                            type: 'integer'
                          },
                          InstanceRunningCount: {
                            type: 'integer'
                          },
                          State: {
                          },
                          LastStateChangeReason: {
                          },
                          CreationDateTime: {
                            type: 'timestamp'
                          },
                          StartDateTime: {
                            type: 'timestamp'
                          },
                          ReadyDateTime: {
                            type: 'timestamp'
                          },
                          EndDateTime: {
                            type: 'timestamp'
                          }
                        }
                      }
                    },
                    NormalizedInstanceHours: {
                      type: 'integer'
                    },
                    Ec2KeyName: {
                    },
                    Ec2SubnetId: {
                    },
                    Placement: {
                      type: 'structure',
                      members: {
                        AvailabilityZone: {
                        }
                      }
                    },
                    KeepJobFlowAliveWhenNoSteps: {
                      type: 'boolean'
                    },
                    TerminationProtected: {
                      type: 'boolean'
                    },
                    HadoopVersion: {
                    }
                  }
                },
                Steps: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      StepConfig: {
                        type: 'structure',
                        members: {
                          Name: {
                          },
                          ActionOnFailure: {
                          },
                          HadoopJarStep: {
                            type: 'structure',
                            members: {
                              Properties: {
                                type: 'list',
                                members: {
                                  type: 'structure',
                                  members: {
                                    Key: {
                                    },
                                    Value: {
                                    }
                                  }
                                }
                              },
                              Jar: {
                              },
                              MainClass: {
                              },
                              Args: {
                                type: 'list',
                                members: {
                                }
                              }
                            }
                          }
                        }
                      },
                      ExecutionStatusDetail: {
                        type: 'structure',
                        members: {
                          State: {
                          },
                          CreationDateTime: {
                            type: 'timestamp'
                          },
                          StartDateTime: {
                            type: 'timestamp'
                          },
                          EndDateTime: {
                            type: 'timestamp'
                          },
                          LastStateChangeReason: {
                          }
                        }
                      }
                    }
                  }
                },
                BootstrapActions: {
                  type: 'list',
                  members: {
                    type: 'structure',
                    members: {
                      BootstrapActionConfig: {
                        type: 'structure',
                        members: {
                          Name: {
                          },
                          ScriptBootstrapAction: {
                            type: 'structure',
                            members: {
                              Path: {
                              },
                              Args: {
                                type: 'list',
                                members: {
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                },
                SupportedProducts: {
                  type: 'list',
                  members: {
                  }
                },
                VisibleToAllUsers: {
                  type: 'boolean'
                },
                JobFlowRole: {
                }
              }
            }
          }
        }
      }
    },
    describeStep: {
      name: 'DescribeStep',
      input: {
        type: 'structure',
        members: {
          ClusterId: {
          },
          StepId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Step: {
            type: 'structure',
            members: {
              Id: {
              },
              Name: {
              },
              Config: {
                type: 'structure',
                members: {
                  Jar: {
                  },
                  Properties: {
                    type: 'map',
                    keys: {
                    },
                    members: {
                    }
                  },
                  MainClass: {
                  },
                  Args: {
                    type: 'list',
                    members: {
                    }
                  }
                }
              },
              ActionOnFailure: {
              },
              Status: {
                type: 'structure',
                members: {
                  State: {
                  },
                  StateChangeReason: {
                    type: 'structure',
                    members: {
                      Code: {
                      },
                      Message: {
                      }
                    }
                  },
                  Timeline: {
                    type: 'structure',
                    members: {
                      CreationDateTime: {
                        type: 'timestamp'
                      },
                      StartDateTime: {
                        type: 'timestamp'
                      },
                      EndDateTime: {
                        type: 'timestamp'
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    listBootstrapActions: {
      name: 'ListBootstrapActions',
      input: {
        type: 'structure',
        members: {
          ClusterId: {
          },
          Marker: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          BootstrapActions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                },
                ScriptPath: {
                },
                Args: {
                  type: 'list',
                  members: {
                  }
                }
              }
            }
          },
          Marker: {
          }
        }
      }
    },
    listClusters: {
      name: 'ListClusters',
      input: {
        type: 'structure',
        members: {
          CreatedAfter: {
            type: 'timestamp'
          },
          CreatedBefore: {
            type: 'timestamp'
          },
          ClusterStates: {
            type: 'list',
            members: {
            }
          },
          Marker: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Clusters: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Name: {
                },
                Status: {
                  type: 'structure',
                  members: {
                    State: {
                    },
                    StateChangeReason: {
                      type: 'structure',
                      members: {
                        Code: {
                        },
                        Message: {
                        }
                      }
                    },
                    Timeline: {
                      type: 'structure',
                      members: {
                        CreationDateTime: {
                          type: 'timestamp'
                        },
                        ReadyDateTime: {
                          type: 'timestamp'
                        },
                        EndDateTime: {
                          type: 'timestamp'
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          Marker: {
          }
        }
      }
    },
    listInstanceGroups: {
      name: 'ListInstanceGroups',
      input: {
        type: 'structure',
        members: {
          ClusterId: {
          },
          Marker: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          InstanceGroups: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Name: {
                },
                Market: {
                },
                InstanceGroupType: {
                },
                BidPrice: {
                },
                InstanceType: {
                },
                RequestedInstanceCount: {
                  type: 'integer'
                },
                RunningInstanceCount: {
                  type: 'integer'
                },
                Status: {
                  type: 'structure',
                  members: {
                    State: {
                    },
                    StateChangeReason: {
                      type: 'structure',
                      members: {
                        Code: {
                        },
                        Message: {
                        }
                      }
                    },
                    Timeline: {
                      type: 'structure',
                      members: {
                        CreationDateTime: {
                          type: 'timestamp'
                        },
                        ReadyDateTime: {
                          type: 'timestamp'
                        },
                        EndDateTime: {
                          type: 'timestamp'
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          Marker: {
          }
        }
      }
    },
    listInstances: {
      name: 'ListInstances',
      input: {
        type: 'structure',
        members: {
          ClusterId: {
          },
          InstanceGroupId: {
          },
          InstanceGroupTypes: {
            type: 'list',
            members: {
            }
          },
          Marker: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Instances: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Ec2InstanceId: {
                },
                PublicDnsName: {
                },
                PublicIpAddress: {
                },
                PrivateDnsName: {
                },
                PrivateIpAddress: {
                },
                Status: {
                  type: 'structure',
                  members: {
                    State: {
                    },
                    StateChangeReason: {
                      type: 'structure',
                      members: {
                        Code: {
                        },
                        Message: {
                        }
                      }
                    },
                    Timeline: {
                      type: 'structure',
                      members: {
                        CreationDateTime: {
                          type: 'timestamp'
                        },
                        ReadyDateTime: {
                          type: 'timestamp'
                        },
                        EndDateTime: {
                          type: 'timestamp'
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          Marker: {
          }
        }
      }
    },
    listSteps: {
      name: 'ListSteps',
      input: {
        type: 'structure',
        members: {
          ClusterId: {
          },
          StepStates: {
            type: 'list',
            members: {
            }
          },
          Marker: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          Steps: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Id: {
                },
                Name: {
                },
                Status: {
                  type: 'structure',
                  members: {
                    State: {
                    },
                    StateChangeReason: {
                      type: 'structure',
                      members: {
                        Code: {
                        },
                        Message: {
                        }
                      }
                    },
                    Timeline: {
                      type: 'structure',
                      members: {
                        CreationDateTime: {
                          type: 'timestamp'
                        },
                        StartDateTime: {
                          type: 'timestamp'
                        },
                        EndDateTime: {
                          type: 'timestamp'
                        }
                      }
                    }
                  }
                }
              }
            }
          },
          Marker: {
          }
        }
      }
    },
    modifyInstanceGroups: {
      name: 'ModifyInstanceGroups',
      input: {
        type: 'structure',
        members: {
          InstanceGroups: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                InstanceGroupId: {
                  required: true
                },
                InstanceCount: {
                  type: 'integer'
                },
                EC2InstanceIdsToTerminate: {
                  type: 'list',
                  members: {
                  }
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    removeTags: {
      name: 'RemoveTags',
      input: {
        type: 'structure',
        members: {
          ResourceId: {
          },
          TagKeys: {
            type: 'list',
            members: {
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    runJobFlow: {
      name: 'RunJobFlow',
      input: {
        type: 'structure',
        members: {
          Name: {
            required: true
          },
          LogUri: {
          },
          AdditionalInfo: {
          },
          AmiVersion: {
          },
          Instances: {
            type: 'structure',
            members: {
              MasterInstanceType: {
              },
              SlaveInstanceType: {
              },
              InstanceCount: {
                type: 'integer'
              },
              InstanceGroups: {
                type: 'list',
                members: {
                  type: 'structure',
                  members: {
                    Name: {
                    },
                    Market: {
                    },
                    InstanceRole: {
                      required: true
                    },
                    BidPrice: {
                    },
                    InstanceType: {
                      required: true
                    },
                    InstanceCount: {
                      type: 'integer',
                      required: true
                    }
                  }
                }
              },
              Ec2KeyName: {
              },
              Placement: {
                type: 'structure',
                members: {
                  AvailabilityZone: {
                    required: true
                  }
                }
              },
              KeepJobFlowAliveWhenNoSteps: {
                type: 'boolean'
              },
              TerminationProtected: {
                type: 'boolean'
              },
              HadoopVersion: {
              },
              Ec2SubnetId: {
              }
            },
            required: true
          },
          Steps: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                ActionOnFailure: {
                },
                HadoopJarStep: {
                  type: 'structure',
                  members: {
                    Properties: {
                      type: 'list',
                      members: {
                        type: 'structure',
                        members: {
                          Key: {
                          },
                          Value: {
                          }
                        }
                      }
                    },
                    Jar: {
                      required: true
                    },
                    MainClass: {
                    },
                    Args: {
                      type: 'list',
                      members: {
                      }
                    }
                  },
                  required: true
                }
              }
            }
          },
          BootstrapActions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                  required: true
                },
                ScriptBootstrapAction: {
                  type: 'structure',
                  members: {
                    Path: {
                      required: true
                    },
                    Args: {
                      type: 'list',
                      members: {
                      }
                    }
                  },
                  required: true
                }
              }
            }
          },
          SupportedProducts: {
            type: 'list',
            members: {
            }
          },
          NewSupportedProducts: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Name: {
                },
                Args: {
                  type: 'list',
                  members: {
                  }
                }
              }
            }
          },
          VisibleToAllUsers: {
            type: 'boolean'
          },
          JobFlowRole: {
          },
          Tags: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                Key: {
                },
                Value: {
                }
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          JobFlowId: {
          }
        }
      }
    },
    setTerminationProtection: {
      name: 'SetTerminationProtection',
      input: {
        type: 'structure',
        members: {
          JobFlowIds: {
            type: 'list',
            members: {
            },
            required: true
          },
          TerminationProtected: {
            type: 'boolean',
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    setVisibleToAllUsers: {
      name: 'SetVisibleToAllUsers',
      input: {
        type: 'structure',
        members: {
          JobFlowIds: {
            type: 'list',
            members: {
            },
            required: true
          },
          VisibleToAllUsers: {
            type: 'boolean',
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    terminateJobFlows: {
      name: 'TerminateJobFlows',
      input: {
        type: 'structure',
        members: {
          JobFlowIds: {
            type: 'list',
            members: {
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    }
  },
  pagination: {
    describeJobFlows: {
      resultKey: 'JobFlows'
    }
  }
};
