/**
 * Copyright 2012-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"). You
 * may not use this file except in compliance with the License. A copy of
 * the License is located at
 *
 *     http://aws.amazon.com/apache2.0/
 *
 * or in the "license" file accompanying this file. This file is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */

module.exports = {
  format: 'json',
  apiVersion: '2012-01-25',
  endpointPrefix: 'swf',
  jsonVersion: '1.0',
  serviceAbbreviation: 'Amazon SWF',
  serviceFullName: 'Amazon Simple Workflow Service',
  signatureVersion: 'v4',
  targetPrefix: 'SimpleWorkflowService',
  timestampFormat: 'unixTimestamp',
  operations: {
    countClosedWorkflowExecutions: {
      name: 'CountClosedWorkflowExecutions',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          startTimeFilter: {
            type: 'structure',
            members: {
              oldestDate: {
                type: 'timestamp',
                required: true
              },
              latestDate: {
                type: 'timestamp'
              }
            }
          },
          closeTimeFilter: {
            type: 'structure',
            members: {
              oldestDate: {
                type: 'timestamp',
                required: true
              },
              latestDate: {
                type: 'timestamp'
              }
            }
          },
          executionFilter: {
            type: 'structure',
            members: {
              workflowId: {
                required: true
              }
            }
          },
          typeFilter: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
              }
            }
          },
          tagFilter: {
            type: 'structure',
            members: {
              tag: {
                required: true
              }
            }
          },
          closeStatusFilter: {
            type: 'structure',
            members: {
              status: {
                required: true
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          count: {
            type: 'integer'
          },
          truncated: {
            type: 'boolean'
          }
        }
      }
    },
    countOpenWorkflowExecutions: {
      name: 'CountOpenWorkflowExecutions',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          startTimeFilter: {
            type: 'structure',
            members: {
              oldestDate: {
                type: 'timestamp',
                required: true
              },
              latestDate: {
                type: 'timestamp'
              }
            },
            required: true
          },
          typeFilter: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
              }
            }
          },
          tagFilter: {
            type: 'structure',
            members: {
              tag: {
                required: true
              }
            }
          },
          executionFilter: {
            type: 'structure',
            members: {
              workflowId: {
                required: true
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          count: {
            type: 'integer'
          },
          truncated: {
            type: 'boolean'
          }
        }
      }
    },
    countPendingActivityTasks: {
      name: 'CountPendingActivityTasks',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          taskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          count: {
            type: 'integer'
          },
          truncated: {
            type: 'boolean'
          }
        }
      }
    },
    countPendingDecisionTasks: {
      name: 'CountPendingDecisionTasks',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          taskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          count: {
            type: 'integer'
          },
          truncated: {
            type: 'boolean'
          }
        }
      }
    },
    deprecateActivityType: {
      name: 'DeprecateActivityType',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          activityType: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    deprecateDomain: {
      name: 'DeprecateDomain',
      input: {
        type: 'structure',
        members: {
          name: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    deprecateWorkflowType: {
      name: 'DeprecateWorkflowType',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          workflowType: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    describeActivityType: {
      name: 'DescribeActivityType',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          activityType: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          typeInfo: {
            type: 'structure',
            members: {
              activityType: {
                type: 'structure',
                members: {
                  name: {
                  },
                  version: {
                  }
                }
              },
              status: {
              },
              description: {
              },
              creationDate: {
                type: 'timestamp'
              },
              deprecationDate: {
                type: 'timestamp'
              }
            }
          },
          configuration: {
            type: 'structure',
            members: {
              defaultTaskStartToCloseTimeout: {
              },
              defaultTaskHeartbeatTimeout: {
              },
              defaultTaskList: {
                type: 'structure',
                members: {
                  name: {
                  }
                }
              },
              defaultTaskScheduleToStartTimeout: {
              },
              defaultTaskScheduleToCloseTimeout: {
              }
            }
          }
        }
      }
    },
    describeDomain: {
      name: 'DescribeDomain',
      input: {
        type: 'structure',
        members: {
          name: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          domainInfo: {
            type: 'structure',
            members: {
              name: {
              },
              status: {
              },
              description: {
              }
            }
          },
          configuration: {
            type: 'structure',
            members: {
              workflowExecutionRetentionPeriodInDays: {
              }
            }
          }
        }
      }
    },
    describeWorkflowExecution: {
      name: 'DescribeWorkflowExecution',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          execution: {
            type: 'structure',
            members: {
              workflowId: {
                required: true
              },
              runId: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          executionInfo: {
            type: 'structure',
            members: {
              execution: {
                type: 'structure',
                members: {
                  workflowId: {
                  },
                  runId: {
                  }
                }
              },
              workflowType: {
                type: 'structure',
                members: {
                  name: {
                  },
                  version: {
                  }
                }
              },
              startTimestamp: {
                type: 'timestamp'
              },
              closeTimestamp: {
                type: 'timestamp'
              },
              executionStatus: {
              },
              closeStatus: {
              },
              parent: {
                type: 'structure',
                members: {
                  workflowId: {
                  },
                  runId: {
                  }
                }
              },
              tagList: {
                type: 'list',
                members: {
                }
              },
              cancelRequested: {
                type: 'boolean'
              }
            }
          },
          executionConfiguration: {
            type: 'structure',
            members: {
              taskStartToCloseTimeout: {
              },
              executionStartToCloseTimeout: {
              },
              taskList: {
                type: 'structure',
                members: {
                  name: {
                  }
                }
              },
              childPolicy: {
              }
            }
          },
          openCounts: {
            type: 'structure',
            members: {
              openActivityTasks: {
                type: 'integer'
              },
              openDecisionTasks: {
                type: 'integer'
              },
              openTimers: {
                type: 'integer'
              },
              openChildWorkflowExecutions: {
                type: 'integer'
              }
            }
          },
          latestActivityTaskTimestamp: {
            type: 'timestamp'
          },
          latestExecutionContext: {
          }
        }
      }
    },
    describeWorkflowType: {
      name: 'DescribeWorkflowType',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          workflowType: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
                required: true
              }
            },
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          typeInfo: {
            type: 'structure',
            members: {
              workflowType: {
                type: 'structure',
                members: {
                  name: {
                  },
                  version: {
                  }
                }
              },
              status: {
              },
              description: {
              },
              creationDate: {
                type: 'timestamp'
              },
              deprecationDate: {
                type: 'timestamp'
              }
            }
          },
          configuration: {
            type: 'structure',
            members: {
              defaultTaskStartToCloseTimeout: {
              },
              defaultExecutionStartToCloseTimeout: {
              },
              defaultTaskList: {
                type: 'structure',
                members: {
                  name: {
                  }
                }
              },
              defaultChildPolicy: {
              }
            }
          }
        }
      }
    },
    getWorkflowExecutionHistory: {
      name: 'GetWorkflowExecutionHistory',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          execution: {
            type: 'structure',
            members: {
              workflowId: {
                required: true
              },
              runId: {
                required: true
              }
            },
            required: true
          },
          nextPageToken: {
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          events: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                eventTimestamp: {
                  type: 'timestamp'
                },
                eventType: {
                },
                eventId: {
                  type: 'integer'
                },
                workflowExecutionStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    input: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskStartToCloseTimeout: {
                    },
                    childPolicy: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    },
                    continuedExecutionRunId: {
                    },
                    parentWorkflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    parentInitiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    result: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                completeWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                failWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    timeoutType: {
                    },
                    childPolicy: {
                    }
                  }
                },
                workflowExecutionCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    details: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                cancelWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionContinuedAsNewEventAttributes: {
                  type: 'structure',
                  members: {
                    input: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    newExecutionRunId: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    taskStartToCloseTimeout: {
                    },
                    childPolicy: {
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    }
                  }
                },
                continueAsNewWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionTerminatedEventAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    },
                    childPolicy: {
                    },
                    cause: {
                    }
                  }
                },
                workflowExecutionCancelRequestedEventAttributes: {
                  type: 'structure',
                  members: {
                    externalWorkflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    externalInitiatedEventId: {
                      type: 'integer'
                    },
                    cause: {
                    }
                  }
                },
                decisionTaskScheduledEventAttributes: {
                  type: 'structure',
                  members: {
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    startToCloseTimeout: {
                    }
                  }
                },
                decisionTaskStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    identity: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    }
                  }
                },
                decisionTaskCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    executionContext: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                decisionTaskTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    timeoutType: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskScheduledEventAttributes: {
                  type: 'structure',
                  members: {
                    activityType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    activityId: {
                    },
                    input: {
                    },
                    control: {
                    },
                    scheduleToStartTimeout: {
                    },
                    scheduleToCloseTimeout: {
                    },
                    startToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    heartbeatTimeout: {
                    }
                  }
                },
                activityTaskStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    identity: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    result: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    timeoutType: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    },
                    details: {
                    }
                  }
                },
                activityTaskCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    details: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    },
                    latestCancelRequestedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskCancelRequestedEventAttributes: {
                  type: 'structure',
                  members: {
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    activityId: {
                    }
                  }
                },
                workflowExecutionSignaledEventAttributes: {
                  type: 'structure',
                  members: {
                    signalName: {
                    },
                    input: {
                    },
                    externalWorkflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    externalInitiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                markerRecordedEventAttributes: {
                  type: 'structure',
                  members: {
                    markerName: {
                    },
                    details: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                recordMarkerFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    markerName: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                timerStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    control: {
                    },
                    startToFireTimeout: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                timerFiredEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                timerCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    startedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                startChildWorkflowExecutionInitiatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    control: {
                    },
                    input: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    childPolicy: {
                    },
                    taskStartToCloseTimeout: {
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                },
                childWorkflowExecutionStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    result: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    reason: {
                    },
                    details: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    timeoutType: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    details: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionTerminatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                signalExternalWorkflowExecutionInitiatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    signalName: {
                    },
                    input: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                externalWorkflowExecutionSignaledEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                signalExternalWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    cause: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                externalWorkflowExecutionCancelRequestedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                requestCancelExternalWorkflowExecutionInitiatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                requestCancelExternalWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    cause: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                scheduleActivityTaskFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    activityType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    activityId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                requestCancelActivityTaskFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    activityId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                startTimerFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                cancelTimerFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                startChildWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    cause: {
                    },
                    workflowId: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                }
              }
            }
          },
          nextPageToken: {
          }
        }
      }
    },
    listActivityTypes: {
      name: 'ListActivityTypes',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          name: {
          },
          registrationStatus: {
            required: true
          },
          nextPageToken: {
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          typeInfos: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                activityType: {
                  type: 'structure',
                  members: {
                    name: {
                    },
                    version: {
                    }
                  }
                },
                status: {
                },
                description: {
                },
                creationDate: {
                  type: 'timestamp'
                },
                deprecationDate: {
                  type: 'timestamp'
                }
              }
            }
          },
          nextPageToken: {
          }
        }
      }
    },
    listClosedWorkflowExecutions: {
      name: 'ListClosedWorkflowExecutions',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          startTimeFilter: {
            type: 'structure',
            members: {
              oldestDate: {
                type: 'timestamp',
                required: true
              },
              latestDate: {
                type: 'timestamp'
              }
            }
          },
          closeTimeFilter: {
            type: 'structure',
            members: {
              oldestDate: {
                type: 'timestamp',
                required: true
              },
              latestDate: {
                type: 'timestamp'
              }
            }
          },
          executionFilter: {
            type: 'structure',
            members: {
              workflowId: {
                required: true
              }
            }
          },
          closeStatusFilter: {
            type: 'structure',
            members: {
              status: {
                required: true
              }
            }
          },
          typeFilter: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
              }
            }
          },
          tagFilter: {
            type: 'structure',
            members: {
              tag: {
                required: true
              }
            }
          },
          nextPageToken: {
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          executionInfos: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                execution: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    }
                  }
                },
                workflowType: {
                  type: 'structure',
                  members: {
                    name: {
                    },
                    version: {
                    }
                  }
                },
                startTimestamp: {
                  type: 'timestamp'
                },
                closeTimestamp: {
                  type: 'timestamp'
                },
                executionStatus: {
                },
                closeStatus: {
                },
                parent: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    }
                  }
                },
                tagList: {
                  type: 'list',
                  members: {
                  }
                },
                cancelRequested: {
                  type: 'boolean'
                }
              }
            }
          },
          nextPageToken: {
          }
        }
      }
    },
    listDomains: {
      name: 'ListDomains',
      input: {
        type: 'structure',
        members: {
          nextPageToken: {
          },
          registrationStatus: {
            required: true
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          domainInfos: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                name: {
                },
                status: {
                },
                description: {
                }
              }
            }
          },
          nextPageToken: {
          }
        }
      }
    },
    listOpenWorkflowExecutions: {
      name: 'ListOpenWorkflowExecutions',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          startTimeFilter: {
            type: 'structure',
            members: {
              oldestDate: {
                type: 'timestamp',
                required: true
              },
              latestDate: {
                type: 'timestamp'
              }
            },
            required: true
          },
          typeFilter: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
              }
            }
          },
          tagFilter: {
            type: 'structure',
            members: {
              tag: {
                required: true
              }
            }
          },
          nextPageToken: {
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          },
          executionFilter: {
            type: 'structure',
            members: {
              workflowId: {
                required: true
              }
            }
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          executionInfos: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                execution: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    }
                  }
                },
                workflowType: {
                  type: 'structure',
                  members: {
                    name: {
                    },
                    version: {
                    }
                  }
                },
                startTimestamp: {
                  type: 'timestamp'
                },
                closeTimestamp: {
                  type: 'timestamp'
                },
                executionStatus: {
                },
                closeStatus: {
                },
                parent: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    }
                  }
                },
                tagList: {
                  type: 'list',
                  members: {
                  }
                },
                cancelRequested: {
                  type: 'boolean'
                }
              }
            }
          },
          nextPageToken: {
          }
        }
      }
    },
    listWorkflowTypes: {
      name: 'ListWorkflowTypes',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          name: {
          },
          registrationStatus: {
            required: true
          },
          nextPageToken: {
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          typeInfos: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                workflowType: {
                  type: 'structure',
                  members: {
                    name: {
                    },
                    version: {
                    }
                  }
                },
                status: {
                },
                description: {
                },
                creationDate: {
                  type: 'timestamp'
                },
                deprecationDate: {
                  type: 'timestamp'
                }
              }
            }
          },
          nextPageToken: {
          }
        }
      }
    },
    pollForActivityTask: {
      name: 'PollForActivityTask',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          taskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            },
            required: true
          },
          identity: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          taskToken: {
          },
          activityId: {
          },
          startedEventId: {
            type: 'integer'
          },
          workflowExecution: {
            type: 'structure',
            members: {
              workflowId: {
              },
              runId: {
              }
            }
          },
          activityType: {
            type: 'structure',
            members: {
              name: {
              },
              version: {
              }
            }
          },
          input: {
          }
        }
      }
    },
    pollForDecisionTask: {
      name: 'PollForDecisionTask',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          taskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            },
            required: true
          },
          identity: {
          },
          nextPageToken: {
          },
          maximumPageSize: {
            type: 'integer'
          },
          reverseOrder: {
            type: 'boolean'
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          taskToken: {
          },
          startedEventId: {
            type: 'integer'
          },
          workflowExecution: {
            type: 'structure',
            members: {
              workflowId: {
              },
              runId: {
              }
            }
          },
          workflowType: {
            type: 'structure',
            members: {
              name: {
              },
              version: {
              }
            }
          },
          events: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                eventTimestamp: {
                  type: 'timestamp'
                },
                eventType: {
                },
                eventId: {
                  type: 'integer'
                },
                workflowExecutionStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    input: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskStartToCloseTimeout: {
                    },
                    childPolicy: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    },
                    continuedExecutionRunId: {
                    },
                    parentWorkflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    parentInitiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    result: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                completeWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                failWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    timeoutType: {
                    },
                    childPolicy: {
                    }
                  }
                },
                workflowExecutionCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    details: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                cancelWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionContinuedAsNewEventAttributes: {
                  type: 'structure',
                  members: {
                    input: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    newExecutionRunId: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    taskStartToCloseTimeout: {
                    },
                    childPolicy: {
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    }
                  }
                },
                continueAsNewWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                workflowExecutionTerminatedEventAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    },
                    childPolicy: {
                    },
                    cause: {
                    }
                  }
                },
                workflowExecutionCancelRequestedEventAttributes: {
                  type: 'structure',
                  members: {
                    externalWorkflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    externalInitiatedEventId: {
                      type: 'integer'
                    },
                    cause: {
                    }
                  }
                },
                decisionTaskScheduledEventAttributes: {
                  type: 'structure',
                  members: {
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    startToCloseTimeout: {
                    }
                  }
                },
                decisionTaskStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    identity: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    }
                  }
                },
                decisionTaskCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    executionContext: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                decisionTaskTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    timeoutType: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskScheduledEventAttributes: {
                  type: 'structure',
                  members: {
                    activityType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    activityId: {
                    },
                    input: {
                    },
                    control: {
                    },
                    scheduleToStartTimeout: {
                    },
                    scheduleToCloseTimeout: {
                    },
                    startToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    heartbeatTimeout: {
                    }
                  }
                },
                activityTaskStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    identity: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    result: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    timeoutType: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    },
                    details: {
                    }
                  }
                },
                activityTaskCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    details: {
                    },
                    scheduledEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    },
                    latestCancelRequestedEventId: {
                      type: 'integer'
                    }
                  }
                },
                activityTaskCancelRequestedEventAttributes: {
                  type: 'structure',
                  members: {
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    activityId: {
                    }
                  }
                },
                workflowExecutionSignaledEventAttributes: {
                  type: 'structure',
                  members: {
                    signalName: {
                    },
                    input: {
                    },
                    externalWorkflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    externalInitiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                markerRecordedEventAttributes: {
                  type: 'structure',
                  members: {
                    markerName: {
                    },
                    details: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                recordMarkerFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    markerName: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                timerStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    control: {
                    },
                    startToFireTimeout: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                timerFiredEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                timerCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    startedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                startChildWorkflowExecutionInitiatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    control: {
                    },
                    input: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                        }
                      }
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    childPolicy: {
                    },
                    taskStartToCloseTimeout: {
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                },
                childWorkflowExecutionStartedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionCompletedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    result: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    reason: {
                    },
                    details: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionTimedOutEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    timeoutType: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionCanceledEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    details: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                childWorkflowExecutionTerminatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    startedEventId: {
                      type: 'integer'
                    }
                  }
                },
                signalExternalWorkflowExecutionInitiatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    signalName: {
                    },
                    input: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                externalWorkflowExecutionSignaledEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                signalExternalWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    cause: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                externalWorkflowExecutionCancelRequestedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowExecution: {
                      type: 'structure',
                      members: {
                        workflowId: {
                        },
                        runId: {
                        }
                      }
                    },
                    initiatedEventId: {
                      type: 'integer'
                    }
                  }
                },
                requestCancelExternalWorkflowExecutionInitiatedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                requestCancelExternalWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                    },
                    runId: {
                    },
                    cause: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                },
                scheduleActivityTaskFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    activityType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    activityId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                requestCancelActivityTaskFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    activityId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                startTimerFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                cancelTimerFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                    },
                    cause: {
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    }
                  }
                },
                startChildWorkflowExecutionFailedEventAttributes: {
                  type: 'structure',
                  members: {
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                        },
                        version: {
                        }
                      }
                    },
                    cause: {
                    },
                    workflowId: {
                    },
                    initiatedEventId: {
                      type: 'integer'
                    },
                    decisionTaskCompletedEventId: {
                      type: 'integer'
                    },
                    control: {
                    }
                  }
                }
              }
            }
          },
          nextPageToken: {
          },
          previousStartedEventId: {
            type: 'integer'
          }
        }
      }
    },
    recordActivityTaskHeartbeat: {
      name: 'RecordActivityTaskHeartbeat',
      input: {
        type: 'structure',
        members: {
          taskToken: {
            required: true
          },
          details: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          cancelRequested: {
            type: 'boolean'
          }
        }
      }
    },
    registerActivityType: {
      name: 'RegisterActivityType',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          name: {
            required: true
          },
          version: {
            required: true
          },
          description: {
          },
          defaultTaskStartToCloseTimeout: {
          },
          defaultTaskHeartbeatTimeout: {
          },
          defaultTaskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            }
          },
          defaultTaskScheduleToStartTimeout: {
          },
          defaultTaskScheduleToCloseTimeout: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    registerDomain: {
      name: 'RegisterDomain',
      input: {
        type: 'structure',
        members: {
          name: {
            required: true
          },
          description: {
          },
          workflowExecutionRetentionPeriodInDays: {
            required: true
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    registerWorkflowType: {
      name: 'RegisterWorkflowType',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          name: {
            required: true
          },
          version: {
            required: true
          },
          description: {
          },
          defaultTaskStartToCloseTimeout: {
          },
          defaultExecutionStartToCloseTimeout: {
          },
          defaultTaskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            }
          },
          defaultChildPolicy: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    requestCancelWorkflowExecution: {
      name: 'RequestCancelWorkflowExecution',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          workflowId: {
            required: true
          },
          runId: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    respondActivityTaskCanceled: {
      name: 'RespondActivityTaskCanceled',
      input: {
        type: 'structure',
        members: {
          taskToken: {
            required: true
          },
          details: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    respondActivityTaskCompleted: {
      name: 'RespondActivityTaskCompleted',
      input: {
        type: 'structure',
        members: {
          taskToken: {
            required: true
          },
          result: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    respondActivityTaskFailed: {
      name: 'RespondActivityTaskFailed',
      input: {
        type: 'structure',
        members: {
          taskToken: {
            required: true
          },
          reason: {
          },
          details: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    respondDecisionTaskCompleted: {
      name: 'RespondDecisionTaskCompleted',
      input: {
        type: 'structure',
        members: {
          taskToken: {
            required: true
          },
          decisions: {
            type: 'list',
            members: {
              type: 'structure',
              members: {
                decisionType: {
                  required: true
                },
                scheduleActivityTaskDecisionAttributes: {
                  type: 'structure',
                  members: {
                    activityType: {
                      type: 'structure',
                      members: {
                        name: {
                          required: true
                        },
                        version: {
                          required: true
                        }
                      },
                      required: true
                    },
                    activityId: {
                      required: true
                    },
                    control: {
                    },
                    input: {
                    },
                    scheduleToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                          required: true
                        }
                      }
                    },
                    scheduleToStartTimeout: {
                    },
                    startToCloseTimeout: {
                    },
                    heartbeatTimeout: {
                    }
                  }
                },
                requestCancelActivityTaskDecisionAttributes: {
                  type: 'structure',
                  members: {
                    activityId: {
                      required: true
                    }
                  }
                },
                completeWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    result: {
                    }
                  }
                },
                failWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    reason: {
                    },
                    details: {
                    }
                  }
                },
                cancelWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    details: {
                    }
                  }
                },
                continueAsNewWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    input: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                          required: true
                        }
                      }
                    },
                    taskStartToCloseTimeout: {
                    },
                    childPolicy: {
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    },
                    workflowTypeVersion: {
                    }
                  }
                },
                recordMarkerDecisionAttributes: {
                  type: 'structure',
                  members: {
                    markerName: {
                      required: true
                    },
                    details: {
                    }
                  }
                },
                startTimerDecisionAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                      required: true
                    },
                    control: {
                    },
                    startToFireTimeout: {
                      required: true
                    }
                  }
                },
                cancelTimerDecisionAttributes: {
                  type: 'structure',
                  members: {
                    timerId: {
                      required: true
                    }
                  }
                },
                signalExternalWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                      required: true
                    },
                    runId: {
                    },
                    signalName: {
                      required: true
                    },
                    input: {
                    },
                    control: {
                    }
                  }
                },
                requestCancelExternalWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    workflowId: {
                      required: true
                    },
                    runId: {
                    },
                    control: {
                    }
                  }
                },
                startChildWorkflowExecutionDecisionAttributes: {
                  type: 'structure',
                  members: {
                    workflowType: {
                      type: 'structure',
                      members: {
                        name: {
                          required: true
                        },
                        version: {
                          required: true
                        }
                      },
                      required: true
                    },
                    workflowId: {
                      required: true
                    },
                    control: {
                    },
                    input: {
                    },
                    executionStartToCloseTimeout: {
                    },
                    taskList: {
                      type: 'structure',
                      members: {
                        name: {
                          required: true
                        }
                      }
                    },
                    taskStartToCloseTimeout: {
                    },
                    childPolicy: {
                    },
                    tagList: {
                      type: 'list',
                      members: {
                      }
                    }
                  }
                }
              }
            }
          },
          executionContext: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    signalWorkflowExecution: {
      name: 'SignalWorkflowExecution',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          workflowId: {
            required: true
          },
          runId: {
          },
          signalName: {
            required: true
          },
          input: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    },
    startWorkflowExecution: {
      name: 'StartWorkflowExecution',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          workflowId: {
            required: true
          },
          workflowType: {
            type: 'structure',
            members: {
              name: {
                required: true
              },
              version: {
                required: true
              }
            },
            required: true
          },
          taskList: {
            type: 'structure',
            members: {
              name: {
                required: true
              }
            }
          },
          input: {
          },
          executionStartToCloseTimeout: {
          },
          tagList: {
            type: 'list',
            members: {
            }
          },
          taskStartToCloseTimeout: {
          },
          childPolicy: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
          runId: {
          }
        }
      }
    },
    terminateWorkflowExecution: {
      name: 'TerminateWorkflowExecution',
      input: {
        type: 'structure',
        members: {
          domain: {
            required: true
          },
          workflowId: {
            required: true
          },
          runId: {
          },
          reason: {
          },
          details: {
          },
          childPolicy: {
          }
        }
      },
      output: {
        type: 'structure',
        members: {
        }
      }
    }
  },
  pagination: {
    getWorkflowExecutionHistory: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'events'
    },
    listActivityTypes: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'typeInfos'
    },
    listClosedWorkflowExecutions: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'executionInfos'
    },
    listDomains: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'domainInfos'
    },
    listOpenWorkflowExecutions: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'executionInfos'
    },
    listWorkflowTypes: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'typeInfos'
    },
    pollForDecisionTask: {
      inputToken: 'nextPageToken',
      outputToken: 'nextPageToken',
      limitKey: 'maximumPageSize',
      resultKey: 'events'
    }
  }
};
